@@ -17,15 +17,15 @@ int main(int argc, char **argv)
 	KCmdLineArgs *args;
 	KAboutData data("fyrdman",
 		I18N_NOOP("Fyrdman"),
-		"0.1",
+		"0.0.8",
 		I18N_NOOP("KDE client for the Hastings1066 game."),
 		KAboutData::License_GPL,
 		I18N_NOOP("Copyright (C) 2002, 2003 Josef Spillner"),
 		I18N_NOOP("This game is part of the GGZ Gaming Zone."),
-		"http://ggz.sourceforge.net/games/fyrdman/",
-		"dr_maux@users.sourceforge.net");
+		"http://www.ggzgamingzone.org/games/fyrdman/",
+		"josef@ggzgamingzone.org");
 
-	data.addAuthor("Josef Spillner", I18N_NOOP("Initial developer"), "josef@ggzgamingzone.org", "http://mindx.dyndns.org");
+	data.addAuthor("Josef Spillner", I18N_NOOP("Initial developer"), "josef@ggzgamingzone.org");
 	data.setTranslator(I18N_NOOP("TRANSLATOR-NAME"), I18N_NOOP("TRANSLATOR-EMAIL"));
 
 	KCmdLineArgs::init(argc, argv, &data);
